==> sceptre-00.317.tar.gz: x1/iceqs.f <==
CSECT   ICEQS
C       26 MAR 73
      SUBROUTINE ICEQS (NERROR)
 
C     PROGRAM TO GENERATE INITIAL CONDITION SOLUTION EQUATIONS.
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z), INTEGER (I-N)
 
	include 'tables.inc'
                      equivalence (iqtabl(3200),nmax)

      COMMON /ELDATA/ EL,NELMTS,LELMTS,ELMNTS(300),XZ(1200),
     *                CMPFLG(300),IVLCOD(600)
         CHARACTER*8  ELMNTS,CMPFLG
      COMMON /SCNTBL/ NBRANS,NLINKS,LENTBL,ISTART(17),LNCLAS(17),
     *                MAT(17),NCL(8)
      COMMON /CNTRLS/ ABCD(43),PRINT
      COMMON /BUFERS/ BUFF,BUFFER(1)
         CHARACTER*4  BUFFER
      CHARACTER*8     DIMCHR(3),DIMSON(3),EQUIVL(5)
      CHARACTER*4     XIBCD
      CHARACTER*8     YICSV,YICSV1
      DIMENSION       INDEX(3)
      CHARACTER*8     ZERO,CTEMP
      INTEGER         IIZERO(2)
         EQUIVALENCE (IIZERO,ZERO)
      CHARACTER*8     COMENT , BLANK
      CHARACTER*8     S1111,S8042,S8050,S8052,S8054
 
      DATA            DIMCHR /'DIMENSIO','N SVVNAM','(   )   '/
      DATA            DIMSON /'DIMENSIO','N SVNAM2','(   )   '/
      DATA            EQUIVL /'EQUIVALE','NCE (SVV','NAM(146)',
     *                        ',SVNAM2(','1))     '/
      DATA            COMENT /'C'/, BLANK /' '/
      DATA            S1111 /' 1111'/,S8042 /' 8042'/,S8050 /' 8050'/,
     *                S8052 /' 8052'/,S8054 /' 8054'/
      DATA            INDEX /7,11,12/
      DATA            IIZERO /0,0/

      CALL ICCFON
   30 CALL ICCHCK (NTNRPH,NERROR)
      IF (NTNRPH.EQ.0) GO TO 100
      IF (PRINT ) 31,40,31
 
C     STATE VARIABLE VALUES.
 
   31 ITOCHR=18
      CALL CPY(XIBCD(LNCLAS(7)+LNCLAS(11)+LNCLAS(12),3,1,N),1,
     *         DIMCHR,ITOCHR,3)
      NUM=LNCLAS(7)+LNCLAS(11)+LNCLAS(12)
      IF(NUM.LE.145) GO TO 20
      ITOCHR=18
      CALL CPY(XIBCD(NUM-145,3,1,N),1,DIMSON,ITOCHR,3)
   20 ITOCHR=1
      CALL CPY('DATA SVVNAM/6HV',1,BUFFER,ITOCHR,15)
      NMR=0
      CALL WTSPTP(BLANK,DIMCHR,21,N)
      DO 34 I=1,3
      J=INDEX(I)
      IF (LNCLAS(J).EQ.0) GO TO 34
      KFIRST=ISTART(J)
      KLAST=KFIRST+LNCLAS(J)-1
      DO 32 K=KFIRST,KLAST
      NMR=NMR+1
      IF(NMR.LT.146) GO TO 25
      CALL WTSPTP(BLANK,DIMSON,21,N)
      CALL WTSPTP(BLANK,EQUIVL,40,N)
      NMR=0
      ITOCHR=ITOCHR-4
      CALL CPY('/',1,BUFFER,ITOCHR,1)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      ITOCHR=1
      CALL CPY('DATA SVNAM2/6HV',1,BUFFER,ITOCHR,15)
   25 CALL CPY(ELMNTS(K),1,BUFFER,ITOCHR,5)
   32 CALL CPY(',6HV',1,BUFFER,ITOCHR,4)
   34 CONTINUE
      ITOCHR=ITOCHR-4
      CALL CPY('/',1,BUFFER,ITOCHR,1)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(BLANK,'IF(XICPRT.EQ.0.D0) WRITE (NOUTTP,1111)',38,N)
      CALL WTSPTP(S1111,
     * 'FORMAT (1H1,48X,35HI/C VOLTAGES ACROSS STATE VARIABLES///)',
     *     58,N)
   40 NICSV=LNCLAS(7)+LNCLAS(11)+LNCLAS(12)
      IF (NICSV) 100,100,35
   35 YICSV=XIBCD(NICSV,3,1,N)
      YICSV1=XIBCD(NICSV+1,3,1,N)
      ITOCHR=1
      CALL CPY('DIMENSION A(   ,   ),AVI(   ),B(   )',1,
     *         BUFFER,ITOCHR,36)
      N=13
      CALL CPY(YICSV ,1,BUFFER,N,3)
      N=17
      CALL CPY(YICSV1,1,BUFFER,N,3)
      N=26
      CALL CPY(YICSV ,1,BUFFER,N,3)
      N=33
      CALL CPY(YICSV ,1,BUFFER,N,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(BLANK,'XICPAS=0.',9,N)
      ITOCHR=1
      CALL CPY('NICSV=',1,BUFFER,ITOCHR,6)
      CALL CPY(YICSV,1,BUFFER,ITOCHR,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      ITOCHR=6
      CALL CPY('1=',1,BUFFER,ITOCHR,2)
      CALL CPY(YICSV1,1,BUFFER,ITOCHR,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(S8042,'XICPAS=XICPAS+1.',16,N)
      CALL WTSPTP(COMENT,'CLEAR AUGMENTED A-MATRIX TO ZEROES',34,N)
      CALL WTSPTP(S8050,'DO 8054 N=1,NICSV',17,N)
      CALL WTSPTP(BLANK,'DO 8052 N1=1,NICSV1',19,N)
      CALL WTSPTP(S8052,'A(N,N1)=0.',10,N)
      CALL WTSPTP(COMENT,
     *     'STORE 1''S ON DIAGONAL OF THE COEFFICIENT MATRIX',47,N)
      CALL WTSPTP(S8054,'A(N,N)=1.',9,N)
      IF( NMAX.LT.NELMTS ) CALL WTSPTP(COMENT,'KEY1',4,N)
      IF (NICSV.NE.0) CALL IEQUTN(NICSV,NERROR)
 
C     TURN OFF FLAGS FOR PRI. AND SEC. DEP. J'S TO GET UPDATED VALUES.
 
      DO 50 I=1,NELMTS
      IF (IVLCOD(I*2).GT.6.AND.IVLCOD(I*2).LT.10) THEN
         CTEMP=CMPFLG(I)(1:5)
         CMPFLG(I)=ZERO
         CMPFLG(I)(1:5)=CTEMP
      END IF
   50 CONTINUE
  100 RETURN
 
      END

==> sceptre-2012.061.tar.gz: x1/iceqs.f <==
CSECT   ICEQS
C       26 MAR 73
      SUBROUTINE ICEQS (NERROR)
 
C     PROGRAM TO GENERATE INITIAL CONDITION SOLUTION EQUATIONS.
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z), INTEGER (I-N)
 
      include 'tables.inc'
                      equivalence (iqtabl(3200),nmax)

      COMMON /ELDATA/ EL,NELMTS,LELMTS,ELMNTS(300),XZ(1200),
     *                CMPFLG(300),IVLCOD(600)
         CHARACTER*8  ELMNTS,CMPFLG
      COMMON /SCNTBL/ NBRANS,NLINKS,LENTBL,ISTART(17),LNCLAS(17),
     *                MAT(17),NCL(8)
      COMMON /CNTRLS/ ABCD(43),PRINT
      COMMON /BUFERS/ BUFF,BUFFER(1)
         CHARACTER*4  BUFFER
      CHARACTER*8     DIMCHR(3),DIMSON(3),EQUIVL(5)
      CHARACTER*4     XIBCD
      CHARACTER*8     YICSV,YICSV1
      DIMENSION       INDEX(3)
      CHARACTER*8     ZERO
      CHARACTER*5     CTEMP
      INTEGER         IIZERO(2)
         EQUIVALENCE (IIZERO,ZERO)
      CHARACTER*8     COMENT , BLANK
      CHARACTER*8     S1111,S8042,S8050,S8052,S8054
 
      DATA            DIMCHR /'DIMENSIO','N SVVNAM','(   )   '/
      DATA            DIMSON /'DIMENSIO','N SVNAM2','(   )   '/
      DATA            EQUIVL /'EQUIVALE','NCE (SVV','NAM(146)',
     *                        ',SVNAM2(','1))     '/
      DATA            COMENT /'C'/, BLANK /' '/
      DATA            S1111 /' 1111'/,S8042 /' 8042'/,S8050 /' 8050'/,
     *                S8052 /' 8052'/,S8054 /' 8054'/
      DATA            INDEX /7,11,12/
      DATA            IIZERO /0,0/

      CALL ICCFON
      CALL ICCHCK (NTNRPH,NERROR)
      IF (NTNRPH.EQ.0) GO TO 100
      IF (PRINT ) 31,40,31
 
C     STATE VARIABLE VALUES.
 
   31 ITOCHR=18
      CALL CPY(XIBCD(LNCLAS(7)+LNCLAS(11)+LNCLAS(12),3,1,N),1,
     *         DIMCHR,ITOCHR,3)
      NUM=LNCLAS(7)+LNCLAS(11)+LNCLAS(12)
      IF(NUM.LE.145) GO TO 20
      ITOCHR=18
      CALL CPY(XIBCD(NUM-145,3,1,N),1,DIMSON,ITOCHR,3)
   20 ITOCHR=1
      CALL CPY('DATA SVVNAM/6HV',1,BUFFER,ITOCHR,15)
      NMR=0
      CALL WTSPTP(BLANK,DIMCHR,21,N)
      DO 34 I=1,3
      J=INDEX(I)
      IF (LNCLAS(J).EQ.0) GO TO 34
      KFIRST=ISTART(J)
      KLAST=KFIRST+LNCLAS(J)-1
      DO 32 K=KFIRST,KLAST
      NMR=NMR+1
      IF(NMR.LT.146) GO TO 25
      CALL WTSPTP(BLANK,DIMSON,21,N)
      CALL WTSPTP(BLANK,EQUIVL,40,N)
      NMR=0
      ITOCHR=ITOCHR-4
      CALL CPY('/',1,BUFFER,ITOCHR,1)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      ITOCHR=1
      CALL CPY('DATA SVNAM2/6HV',1,BUFFER,ITOCHR,15)
   25 CALL CPY(ELMNTS(K),1,BUFFER,ITOCHR,5)
   32 CALL CPY(',6HV',1,BUFFER,ITOCHR,4)
   34 CONTINUE
      ITOCHR=ITOCHR-4
      CALL CPY('/',1,BUFFER,ITOCHR,1)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(BLANK,'IF(XICPRT.EQ.0.D0) WRITE (NOUTTP,1111)',38,N)
      CALL WTSPTP(S1111,
     * 'FORMAT (1H1,48X,35HI/C VOLTAGES ACROSS STATE VARIABLES///)',
     *     58,N)
   40 NICSV=LNCLAS(7)+LNCLAS(11)+LNCLAS(12)
      IF (NICSV) 100,100,35
   35 YICSV=XIBCD(NICSV,3,1,N)
      YICSV1=XIBCD(NICSV+1,3,1,N)
      ITOCHR=1
      CALL CPY('DIMENSION A(   ,   ),AVI(   ),B(   )',1,
     *         BUFFER,ITOCHR,36)
      N=13
      CALL CPY(YICSV ,1,BUFFER,N,3)
      N=17
      CALL CPY(YICSV1,1,BUFFER,N,3)
      N=26
      CALL CPY(YICSV ,1,BUFFER,N,3)
      N=33
      CALL CPY(YICSV ,1,BUFFER,N,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(BLANK,'XICPAS=0.',9,N)
      ITOCHR=1
      CALL CPY('NICSV=',1,BUFFER,ITOCHR,6)
      CALL CPY(YICSV,1,BUFFER,ITOCHR,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      ITOCHR=6
      CALL CPY('1=',1,BUFFER,ITOCHR,2)
      CALL CPY(YICSV1,1,BUFFER,ITOCHR,3)
      CALL WTSPTP(BLANK,BUFFER,ITOCHR-1,N)
      CALL WTSPTP(S8042,'XICPAS=XICPAS+1.',16,N)
      CALL WTSPTP(COMENT,'CLEAR AUGMENTED A-MATRIX TO ZEROES',34,N)
      CALL WTSPTP(S8050,'DO 8054 N=1,NICSV',17,N)
      CALL WTSPTP(BLANK,'DO 8052 N1=1,NICSV1',19,N)
      CALL WTSPTP(S8052,'A(N,N1)=0.',10,N)
      CALL WTSPTP(COMENT,
     *     'STORE 1''S ON DIAGONAL OF THE COEFFICIENT MATRIX',47,N)
      CALL WTSPTP(S8054,'A(N,N)=1.',9,N)
      IF( NMAX.LT.NELMTS ) CALL WTSPTP(COMENT,'KEY1',4,N)
      IF (NICSV.NE.0) CALL IEQUTN(NICSV,NERROR)
 
C     TURN OFF FLAGS FOR PRI. AND SEC. DEP. J'S TO GET UPDATED VALUES.
 
      DO 50 I=1,NELMTS
      IF (IVLCOD(I*2).GT.6.AND.IVLCOD(I*2).LT.10) THEN
         CTEMP=CMPFLG(I)(1:5)
         CMPFLG(I)=ZERO
         CMPFLG(I)(1:5)=CTEMP
      END IF
   50 CONTINUE
  100 RETURN
 
      END
